==> c360-styling-hooks-0.2.0.tgz: package/.build/font.register-props.js <==
if (CSS.registerProperty) {
  /* System font stack for your application. */
  CSS.registerProperty({
    name: "--c360-g-font-family-display",
    syntax: "<length>",
    inherits: true,
    initialValue: "'ITC Avant Garde', system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'",
  });
  /* System font stack for your application. */
  CSS.registerProperty({
    name: "--c360-g-font-family-sans",
    syntax: "<length>",
    inherits: true,
    initialValue: "'Salesforce Sans', system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'",
  });
  /* Monospace font stack for your application. */
  CSS.registerProperty({
    name: "--c360-g-font-family-monospace",
    syntax: "<length>",
    inherits: true,
    initialValue: "Consolas, Menio, Monaco, Courier, monospace",
  });
  /* Scaled font-size that is 1 stop bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-1",
    syntax: "<length>",
    inherits: false,
    initialValue: "0.75rem",
  });
  /* Scaled font-size that is 2 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-2",
    syntax: "<length>",
    inherits: false,
    initialValue: "0.875rem",
  });
  /* Scaled font-size that is 3 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-3",
    syntax: "<length>",
    inherits: false,
    initialValue: "1rem",
  });
  /* Scaled font-size that is 4 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-4",
    syntax: "<length>",
    inherits: false,
    initialValue: "1.25rem",
  });
  /* Scaled font-size that is 5 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-5",
    syntax: "<length>",
    inherits: false,
    initialValue: "1.5rem",
  });
  /* Scaled font-size that is 6 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-6",
    syntax: "<length>",
    inherits: false,
    initialValue: "2rem",
  });
  /* Scaled font-size that is 7 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-7",
    syntax: "<length>",
    inherits: false,
    initialValue: "2.5rem",
  });
  /* Scaled font-size that is 8 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-8",
    syntax: "<length>",
    inherits: false,
    initialValue: "3rem",
  });
  /* Scaled font-size that is 9 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-9",
    syntax: "<length>",
    inherits: false,
    initialValue: "3.5rem",
  });
  /* Scaled font-size that is 10 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-10",
    syntax: "<length>",
    inherits: false,
    initialValue: "5rem",
  });
}

==> c360-styling-hooks-0.2.2.tgz: package/.build/font.register-props.js <==
if (CSS.registerProperty) {
  /* System font stack for your application. */
  CSS.registerProperty({
    name: "--c360-g-font-family-display",
    syntax: "<length>",
    inherits: true,
    initialValue: "'ITC Avant Garde', system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'",
  });
  /* System font stack for your application. */
  CSS.registerProperty({
    name: "--c360-g-font-family-sans",
    syntax: "<length>",
    inherits: true,
    initialValue: "'Salesforce Sans', system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'",
  });
  /* Monospace font stack for your application. */
  CSS.registerProperty({
    name: "--c360-g-font-family-monospace",
    syntax: "<length>",
    inherits: true,
    initialValue: "Consolas, Menlo, Monaco, Courier, monospace",
  });
  /* Scaled font-size that is 1 stop bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-1",
    syntax: "<length>",
    inherits: false,
    initialValue: "0.75rem",
  });
  /* Scaled font-size that is 2 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-2",
    syntax: "<length>",
    inherits: false,
    initialValue: "0.875rem",
  });
  /* Scaled font-size that is 3 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-3",
    syntax: "<length>",
    inherits: false,
    initialValue: "1rem",
  });
  /* Scaled font-size that is 4 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-4",
    syntax: "<length>",
    inherits: false,
    initialValue: "1.25rem",
  });
  /* Scaled font-size that is 5 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-5",
    syntax: "<length>",
    inherits: false,
    initialValue: "1.5rem",
  });
  /* Scaled font-size that is 6 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-6",
    syntax: "<length>",
    inherits: false,
    initialValue: "2rem",
  });
  /* Scaled font-size that is 7 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-7",
    syntax: "<length>",
    inherits: false,
    initialValue: "2.5rem",
  });
  /* Scaled font-size that is 8 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-8",
    syntax: "<length>",
    inherits: false,
    initialValue: "3rem",
  });
  /* Scaled font-size that is 9 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-9",
    syntax: "<length>",
    inherits: false,
    initialValue: "3.5rem",
  });
  /* Scaled font-size that is 10 stops bigger than the base. */
  CSS.registerProperty({
    name: "--c360-g-font-size-10",
    syntax: "<length>",
    inherits: false,
    initialValue: "5rem",
  });
}
